@@ -1,29 +1,33 @@
 #[macro_use]
 extern crate diesel;
-extern crate dotenv;
+#[macro_use]
+extern crate diesel_migrations;
+
+mod config;
+mod core;
+mod models;
+mod schema;
+mod storage;
+mod widgets;
 
 use anyhow::Result;
 use relm4::{adw, gtk, RelmApp};
 use widgets::app::AppModel;
+use diesel_migrations::embed_migrations;
+
 use crate::adw::prelude::ApplicationExt;
+use crate::config::{load_css, set_debug_options};
 
-use crate::config::{load_css, set_app};
-
-mod config;
-mod models;
-mod schema;
-mod services;
-mod storage;
-mod widgets;
+embed_migrations!("migrations");
 
 fn main() -> Result<()> {
     let application = adw::Application::builder()
-        .application_id("do.edfloreshz.github")
+        .application_id("org.devloop.Do")
         .flags(gtk::gio::ApplicationFlags::HANDLES_OPEN)
         .build();
     application.connect_startup(|_| load_css());
-    set_app()?;
-    let model = AppModel::new("");
+    set_debug_options()?;
+    let model = AppModel::new();
     let app = RelmApp::with_app(model, application);
     app.run();
     Ok(())
