@@ -4,7 +4,7 @@ table! {
         display_name -> Text,
         is_owner -> Bool,
         count -> Integer,
-        icon_name -> Text,
+        icon_name -> Nullable<Text>,
     }
 }
 
@@ -13,16 +13,16 @@ table! {
         id_task -> Text,
         id_list -> Text,
         title -> Text,
-        body -> Text,
+        body -> Nullable<Text>,
         completed_on -> Nullable<Text>,
         due_date -> Nullable<Text>,
-        importance -> Text,
+        importance -> Nullable<Text>,
         favorite -> Bool,
         is_reminder_on -> Bool,
         reminder_date -> Nullable<Text>,
-        status -> Text,
-        created_date_time -> Text,
-        last_modified_date_time -> Text,
+        status -> Nullable<Text>,
+        created_date_time -> Nullable<Text>,
+        last_modified_date_time -> Nullable<Text>,
     }
 }
 
