@@ -1,16 +1,13 @@
 use diesel::prelude::*;
 use diesel::sqlite::SqliteConnection;
-use dotenv::dotenv;
-use std::env;
 
-pub struct DatabaseConnection {}
+pub struct DatabaseConnection;
 
 impl DatabaseConnection {
     pub fn establish_connection() -> SqliteConnection {
-        dotenv().ok();
-
-        let database_url = env::var("DATABASE_URL").expect("DATABASE_URL must be set");
-        SqliteConnection::establish(&database_url)
+        let database_path = dirs::data_dir().unwrap().join("do/org.devloop.Do.db");
+        let database_url = database_path.to_str().unwrap();
+        SqliteConnection::establish(database_url)
             .unwrap_or_else(|_| panic!("Error connecting to {}", database_url))
     }
 }
